import React from 'react'
import PropTypes from 'prop-types'
import { css } from 'glamor'
import cx from 'classnames'
import * as enhancers from '../enhancers'

const enhancersArray = Object.keys(enhancers).map(key => enhancers[key])

const propTypes = enhancersArray.reduce((memo, { propTypes }) => {
  if (propTypes) memo = { ...memo, ...propTypes }
}, {
  onRef: PropTypes.func,
  is: PropTypes.oneOfType([
    PropTypes.string,
    PropTypes.element,
    PropTypes.func
  ])
})

const parseProps = (props) => {
  return enhancersArray.reduce((props, { parseProps }) => {
    if (parseProps) props = parseProps(props)
    return props
  }, props)
}

const n = 'ui-lib-box'

// Add these styles globally until glamor properly supports &:matches

css.global(`article.${n}, aside.${n}, details.${n}, figcaption.${n}, figure.${n}, footer.${n}, header.${n}, hgroup.${n}, menu.${n}, nav.${n}, section.${n}`, {
  display: 'block'
})

css.global(`ol.${n}, ul.${n}`, {
  listStyle: 'none'
})

css.global(`bloquote.${n}, q.${n}`, {
  quotes: 'none'
})

css.global(`table.${n}`, {
  borderCollapse: 'collapse',
  borderSpacing: '0'
})

css.global(`input.${n}, textarea.${n}`, {
  outline: 'none'
})

css.global(`strong.${n}`, {
  fontWeight: '500'
})

css.global(`em.${n}`, {
  fontStyle: 'italic'
})

css.global(`*.${n}, *.${n}:before, *.${n}:after`, {
  boxSizing: 'border-box'
})

const cssBaseStyles = css({
  margin: '0',
  padding: '0',
  border: '0',
  verticalAlign: 'baseline',
  MozOsxFontSmoothing: 'grayscale',
  WebkitFontSmoothing: 'antialiased',
  fontSmoothing: 'antialiased'
})

class Box extends React.Component {
  render () {
    const { is, theme, onRef, ...restProps} = this.props // eslint-disable-line
    const { className, ...parsedProps } = parseProps(restProps)
    return React.createElement(is, {
      ...parsedProps,
      className: cx(n, `${cssBaseStyles}`, className),
      ...(onRef ? {
        ref: (node) => { onRef(node) }
      } : {})
    })
  }
}

Box.propTypes = propTypes

Box.defaultProps = {
  is: 'div'
}

Box.displayName = 'Box'

export default Box
