import React from 'react'
import Pane from './Pane'
import { css } from 'glamor'
import SyntaxHighlighter, { registerLanguage } from 'react-syntax-highlighter/dist/light'
import docco from 'react-syntax-highlighter/dist/styles/docco'
import gradle from 'highlight.js/lib/languages/gradle'
import java from 'highlight.js/lib/languages/java'
import javascript from 'highlight.js/lib/languages/javascript'
import objectivec from 'highlight.js/lib/languages/objectivec'
import xml from 'highlight.js/lib/languages/xml'
import theme from './theme'
const { minorScale, majorScale } = theme

registerLanguage('gradle', gradle)
registerLanguage('java', java)
registerLanguage('javascript', javascript)
registerLanguage('objectivec', objectivec)
registerLanguage('xml', xml)

const segmentStyle = {
  ...docco,
  hljs: {
    ...docco.hljs,
    background: 'transparent',
    padding: `${majorScale(1)} ${minorScale(3)}`
  }
}

const styles = {
  '& > pre': {
    margin: 0
  }
}

const CodeBlock = ({ children, codeStyle, language, style, ...props }) =>
  <Pane {...css(styles)} {...props}>
    <SyntaxHighlighter language={language} style={codeStyle}>{children}</SyntaxHighlighter>
  </Pane>

CodeBlock.propTypes = {
  ...Pane.propTypes,
  ...SyntaxHighlighter.propTypes
}

CodeBlock.defaultProps = {
  overflow: 'hidden',
  textAlign: 'left',
  tint: true,
  rounded: true,
  border: true,
  textStyle: 'mono',
  language: 'javascript',
  codeStyle: segmentStyle
}

export default CodeBlock
