import React from 'react'
import { css } from 'glamor'
import Pane from './Pane'
import Text from './Text'
import Link from './Link'
import Triangle from './Triangle'
import theme from './theme'
const { minorScale, majorScale } = theme

const SidebarLink = ({ children, active, ...props }) =>
  <Link textStyle='body1' {...css({
    '&:hover, &.active': {
      backgroundColor: theme.rawColors.blue50
    }
  })} active={active} {...props}>
    <Text is='span' flexAuto>{children}</Text>
    {active ? <Triangle aim='right' fill={theme.intent.secondary.active.linkColor} /> : null}
  </Link>

SidebarLink.defaultProps = {
  is: 'a',
  secondary: true,
  display: 'flex',
  alignItems: 'center',
  paddingX: majorScale(1),
  paddingY: minorScale(1),
  marginBottom: minorScale(1),
  rounded: true
}

const Sidebar = props => <Pane {...props} />

Sidebar.defaultProps = {
  white: true,
  borderRight: true,
  width: majorScale(30),
  padding: majorScale(2),
  flex: '0 0 auto'
}

export {
  Sidebar,
  SidebarLink
}
