import React from 'react'
import PropTypes from 'prop-types'
import Spinner from './Spinner'
import theme from './theme'
const { majorScale } = theme

const defaultSpinnerProps = {
  marginX: 'auto',
  marginY: majorScale(8)
}

export default function (ComposedComponent, spinnerProps) {
  spinnerProps = Object.assign({}, defaultSpinnerProps, spinnerProps)

  function withLoader (props) {
    return props.isLoading
      ? <Spinner {...spinnerProps} />
      : <ComposedComponent {...props} />
  }

  withLoader.displayName = `withLoader(${ComposedComponent.displayName})`

  withLoader.propTypes = {
    isLoading: PropTypes.bool.isRequired
  }

  return withLoader
}
