import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  Box,
  Code,
  Pane,
  theme
} from '../components'
import Content from './Content'
const { majorScale } = theme

export default function boxStory (module) {
  storiesOf('Box', module)
    .add('usage', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Box

The Box component is the base component for most other components, by default it is a \`div\`.
All the higher order components in \`enhancers\` are applied to Box.

## is='...' API

\`\`\`
<Box>div by default</Box>
<Box is='span'>now a span</Box>
<Box is='h1'>now a h1</Box>
<Box is='a'>now a anchor tag</Box>
<Box is={Link}>now a Link, use with caution</Box>
\`\`\`

## Display API

Available on \`<Box />\` or \`withDisplay(Comp)\`.
Uses inline styles.

\`\`\`
<Box display='block' />
<Box display='inline-block' />
<Box display='flex' />
\`\`\`

prop | value | description
-----|-------|-------------
\`display\`| block, inline-block, inline, table, table-row, table-cell, flex, inline-flex | display: x;

## Dimensions API

Available on \`<Box />\` or \`withDimensions(Comp)\`.
Uses inline styles.

\`\`\`
<Box width='200px' />
<Box height='40px' />
<Box height='40px' width='40px' />
<Box minWidth='100px' />
\`\`\`

prop | type | description
-----|------| -------
\`height\`| string | height: x;
\`width\`| string | width: x;
\`minWidth\`| string | min-width: x;
\`minHeight\`| string | min-height: x;
\`maxWidth\`| string | max-width: x;
\`maxHeight\`| string | max-height: x;

## Text Styles API

Available on \`<Box />\` or \`withTextStyles(Comp)\`. Uses glamor.

\`\`\`
<Box textStyle='display1'>Display (1)</Box>
<Box textStyle='display2'>Display 2</Box>
<Box textStyle='display3'>Display 3</Box>
<Box textStyle='display4'>Display 4</Box>
<Box textStyle='display5'>Display 5</Box>
<Box textStyle='body1'>Body (1)</Box>
<Box textStyle='body2'>Body 2</Box>
<Box textStyle='mono'>Mono</Box>
<Box textStyle='caps1'>Caps 1</Box>
<Box textStyle='caps2'>Caps 2</Box>
\`\`\`

`}
          </Content>
          <Box textStyle='display1'>Display (1)</Box>
          <Box textStyle='display2'>Display 2</Box>
          <Box textStyle='display3'>Display 3</Box>
          <Box textStyle='display4'>Display 4</Box>
          <Box textStyle='display5'>Display 5</Box>
          <Box textStyle='body1'>Body (1)</Box>
          <Box textStyle='body2'>Body 2</Box>
          <Box textStyle='mono'>Mono</Box>
          <Box textStyle='caps1'>Caps 1</Box>
          <Box textStyle='caps2'>Caps 2</Box>
          <Content markdown>
            {`

prop | type | description
-----|------|------------
\`textStyle\` | display1, display2, display3, display4, body1, body2, mono, caps1, caps2 | use text style

## Spacing API

Available on \`<Box />\` or \`withSpacing(Comp)\`.
Uses inline styles. Uses the spacing scale.

\`\`\`
<Box padding={majorScale(2)} />
<Box margin={majorScale(2)} />
<Box paddingTop={minorScale(3)} paddingBottom={minorScale(3)} />

<!-- DANGER: Avoid this as much as possible -->
<Box marginTop='-2px' />
\`\`\`

prop | type | description
-----|------| -------
\`padding\` | string | padding: x;
\`paddingTop\` | string | padding-top: x;
\`paddingRight\` | string | padding-right: x;
\`paddingBottom\` | string | padding-bottom: x;
\`paddingLeft\` | string | padding-left: x;
\`paddingLeft\` | string | padding-left: x;
\`paddingX\` | string | padding-left: x; padding-right: x;
\`paddingY\` | string | padding-top: x; padding-bottom: x;
\`marginTop\` | string | margin-top: x;
\`marginRight\` | string | margin-right: x;
\`marginBottom\` | string | margin-bottom: x;
\`marginLeft\` | string | margin-left: x;
\`marginX\` | string | margin-left: x; margin-right: x;
\`marginY\` | string | margin-top: x; margin-bottom: x;

### Spacing Scale

\`\`\`
import {
  theme
} from '@segment/react-ui-library'
const { minorScale, majorScale } = theme
\`\`\`

These scales are super simple:

\`\`\`
const majorScale = x => \`$\{x * 8}px\`
const minorScale = x => \`$\{x * 4}px\`
\`\`\`

# Flex API

Uses glamor.

Need a flexbox refresher? [Complete guide to flexbox](https://css-tricks.com/snippets/css/a-guide-to-flexbox/)

\`\`\`
<Box display='flex'>
  <Pane dark padding={majorScale(2)} width='25%'>Left</Pane>
  <Pane tint={2} padding={majorScale(2)} flexAuto>Main</Pane>
  <Pane dark padding={majorScale(2)} width='25%'>Right</Pane>
</Box>
\`\`\`
`}
          </Content>
          <Box display='flex'>
            <Pane dark padding={majorScale(2)} width='25%' flex='0 0 auto'>Left</Pane>
            <Pane tint={2} flexAuto padding={majorScale(2)}>Main</Pane>
            <Pane dark padding={majorScale(2)} width='25%' flex='0 0 auto'>Right</Pane>
          </Box>
          <Content markdown>
            {`
prop | type | description
-----|------|------------
\`flex\`    | string | flex: x;
\`flexWrap\`    | boolean | flex-wrap: wrap
\`flexAlign\`   | string  | align-items
\`justifyContent\` | center, space-around, space-between, flex-start, flex-end  | justify-content
\`flexDirection\`| row, row-reverse, column, column-reverse | flex-direction: x
\`flexColumn\`| boolean | flex-direction: column; overwrites \`flexDirection\`
\`flexGrow\`| string | flex-grow: x
\`flexShrink\`| string | flex-shrink: x
\`flexAuto\`| boolean | flex: 1 1 auto
\`flexNone\`| boolean | flex: none
\`flexOrder\`   | number  | order

## Borders API

Uses inline styles.

Some components implement a border color already, such as Pane.

prop | type | description
-----|------|------------
\`borderColor\` | string | border-color: x;
\`border\` | boolean | border: 1px solid;
\`borderLeft\` | boolean | border-left: 1px solid;
\`borderRight\` | boolean | border-right: 1px solid;
\`borderTop\` | boolean | border-top: 1px solid;
\`borderBottom\` | boolean | border-bottom: 1px solid;

## Position API

Uses inline styles.

prop | type | description
-----|------|------------
\`position\` | relative, absolute, fixed, static | position: x;
\`top\` | string | top: x;
\`right\` | string | right: x;
\`bottom\` | string | bottom: x;
\`left\` | string | left: x;

## Rounded API (border radius)

Available on \`<Box />\` or \`withRounded(Comp)\`. Uses inline styles.

prop | type | description
-----|------|------------
\`circle\` | bool | border-radius: 9999px
\`rounded\` | bool/1..2/string | adds border radius
\`roundedTop\` | bool/1..2/string | adds border radius
\`roundedTopLeft\` | bool/1..2/string | adds border radius
\`roundedTopRight\` | bool/1..2/string | adds border radius
\`roundedBottom\` | bool/1..2/string | adds border radius
\`roundedBottomLeft\` | bool/1..2/string | adds border radius
\`roundedBottomRight\` | bool/1..2/string | adds border radius
\`roundedLeft\` | bool/1..2/string | adds border radius
\`roundedRight\` | bool/1..2/string | adds border radius

The borderRadius scale contains 1: '5px' and 2: '8px'

`}
          </Content>
          <Pane marginY={majorScale(2)} padding={majorScale(2)} dark circle>circle</Pane>
          <Pane marginY={majorScale(2)} padding={majorScale(2)} dark rounded>rounded</Pane>
          <Pane marginY={majorScale(2)} padding={majorScale(2)} dark roundedTop>roundedTop</Pane>
          <Pane marginY={majorScale(2)} padding={majorScale(2)} dark roundedTopLeft>roundedTopLeft</Pane>
          <Pane marginY={majorScale(2)} padding={majorScale(2)} dark roundedTopRight>roundedTopRight</Pane>
          <Pane marginY={majorScale(2)} padding={majorScale(2)} dark roundedBottom>roundedBottom</Pane>
          <Pane marginY={majorScale(2)} padding={majorScale(2)} dark roundedBottomLeft>roundedBottomLeft</Pane>
          <Pane marginY={majorScale(2)} padding={majorScale(2)} dark roundedBottomRight>roundedBottomRight</Pane>
          <Pane marginY={majorScale(2)} padding={majorScale(2)} dark roundedLeft>roundedLeft</Pane>
          <Pane marginY={majorScale(2)} padding={majorScale(2)} dark roundedRight>roundedRight</Pane>
          <Content markdown>
            {`

## Overflow API

Available on \`<Box />\` or \`withOverflow(Comp)\`. Uses inline styles.

prop | type | description
-----|------|------------
\`overflow\` | hidden, visible, scroll, auto, inherit, initial | overflow: x;


## Shadow API

Available on \`<Box />\` or \`withShadow(Comp)\`. Uses glamor.

prop | type | description
-----|------|------------
\`shadow\` | boolean/1..2 | 1 | box-shadow: x;

`}
          </Content>
          <Pane tint={2} clearfix>
            <Pane white padding={majorScale(2)} margin={majorScale(2)} rounded shadow>Shadow (1)</Pane>
            <Pane white padding={majorScale(2)} margin={majorScale(2)} rounded shadow={2}>Shadow 2</Pane>
          </Pane>
          <Content markdown>
            {`

## Text Align API

Available on \`<Box />\` or \`withTextAlign(Comp)\`. Uses inline styles.

prop | type | description
-----|------|------------
\`textAlign\` | left, center, right | text-align: x;

## Truncate API

Available on \`<Box />\` or \`withTruncate(Comp)\`. Uses inline styles.

prop | type | description
-----|------|------------
\`truncate\` | boolean | sets overflow ellipsis and props to make it work

## Background API

Available on \`<Box />\` or \`withBackground(Comp)\`. Uses glamor.
Pane implements shorthands for this.

prop | type | description
-----|------|-------------
\`background\` | ${Object.keys(theme.backgrounds).join(', ')} |  sets background-color, border-color and color
\`interactive\` | bool | adds styling on hover and active

`}
          </Content>
          <Box background='dark' clearfix>
            <Box background='white' padding={majorScale(2)} margin={majorScale(2)}>background='white'</Box>
            <Box background='tint' padding={majorScale(2)} margin={majorScale(2)}>background='tint'</Box>
            <Box background='tint1' padding={majorScale(2)} margin={majorScale(2)}>background='tint' === background='tint1'</Box>
            <Box background='tint2' padding={majorScale(2)} margin={majorScale(2)}>background='tint2'</Box>
          </Box>
          <Content markdown>
            {`

## Background color API

Uses inline styles.

This is only used as an escape hatch in most cases.
\`<Pane white|tint|dark />\` should be used in general.

prop | type | default | description
-----|------|---------|-------------
\`backgroundColor\` | string | | background-color: x;

## Transform API

Uses glamor.

prop | type | description
-----|------|------------
\`transform\` | string | transform: x;

## Clearfix API

Uses glamor.

prop | type | description
-----|------|------------
\`clearfix\` | boolean | | applies a clearfix

`}
          </Content>
        </Pane>
      </App>
    ))
    .add('standalone', () => (
      <Box
        background='dark'
        padding={majorScale(2)}
        margin={majorScale(2)}
        rounded
        shadow
        textAlign='center'>
        <Code>{'<Box background=\'dark\' padding={majorScale(2)} margin={majorScale(2)} rounded shadow textAlign=\'center\' />'}</Code>
      </Box>
    ))
    .add('deprecation warning', () => (
      <div>
        <Box padding />
        <Box paddingLeft={3} />
      </div>
    ))
}
