import React, {Component} from 'react'
import {storiesOf} from '@kadira/storybook'
import {
  App,
  Pane,
  Button,
  Dialog,
  theme
} from '../components'
import Content from './Content'
const {majorScale} = theme

class DialogExample extends Component {
  constructor () {
    super()

    this.state = {
      isOpen: false
    }

    this.toggleDialog = this.toggleDialog.bind(this)
  }

  render () {
    const {isOpen} = this.state

    return (
      <Pane display='flex' flexDirection='column' alignItems='center'>
        <Button primary onClick={this.toggleDialog}>Open Dialog</Button>
        <Dialog isOpen={isOpen} onClose={this.toggleDialog} title='In-development feature'>
          <Pane is='p'>
            We’re excited to have you preview this in-development feature.
            Note that this feature does not meet the standards of a finished
            product and should only be used with a source-to-source repeater to
            ensure data reliability.
          </Pane>
          <Button primary onClick={this.toggleDialog} marginTop={majorScale(3)}>
            I Understand The Risks
          </Button>
        </Dialog>
      </Pane>
    )
  }

  toggleDialog () {
    this.setState((prevState) => ({isOpen: !prevState.isOpen}))
  }
}

export default function (module) {
  storiesOf('Dialog', module)
    .add('usage', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Dialog

The Dialog component. Implements \`<Box />\`.

\`\`\`
class DialogExample extends Component {
  constructor () {
    super()

    this.state = {
      isOpen: false
    }

    this.toggleDialog = this.toggleDialog.bind(this)
  }

  render () {
    const {isOpen} = this.state

    return (
      <Pane display='flex' flexDirection='column' alignItems='center'>
        <Button primary onClick={this.toggleDialog}>Open Dialog</Button>
        <Dialog isOpen={isOpen} onClose={this.toggleDialog} title='In-development feature'>
          <Pane is='p'>
            We’re excited to have you preview this in-development feature.
            Note that this feature does not meet the standards of a finished
            product and should only be used with a source-to-source repeater to
            ensure data reliability.
          </Pane>
          <Button primary onClick={this.toggleDialog} marginTop={majorScale(3)}>
            I Understand The Risks
          </Button>
        </Dialog>
      </Pane>
    )
  }

  toggleDialog () {
    this.setState((prevState) => ({isOpen: !prevState.isOpen}))
  }
}
\`\`\`
`}
          </Content>

          <DialogExample />

          <Content markdown>
            {`
prop | version | type | default | description
-----|---------|------| --------|----------
\`title\`| v7.1.0 | \`node\` | \`undefined\` | title of the dialog
\`isOpen\`| v7.1.0 | \`boolean\` | \`false\` | whether the dialog is open or not
\`children\`| v7.1.0 | \`node\` | \`undefined\` | contents of the dialog
\`onClose\`| v7.1.0 | \`function\` | \`undefined\` | [optional] called when the close button or overlay is clicked
`}
          </Content>
        </Pane>
      </App>
    ))
}
