import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  Pane,
  NavigationBar,
  Avatar,
  Box,
  Triangle,
  theme
} from '../components'
import Content from './Content'
const { majorScale } = theme

const AvatarWithTriangle = () =>
  <Box display='inline-flex' alignItems='center'>
    <Avatar marginLeft={majorScale(1)} marginRight={majorScale(1)} src='' imageSize='small'>Segment Sloth</Avatar>
    <Triangle aim='down' display='inline-flex' fill='white' />
  </Box>

export default function navigationBarStory (module) {
  storiesOf('Navigation Bar', module)
    .add('usage', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Navigation Bar

The NavigationBar component. Composes \`<Pane />\`.

\`\`\`
const AvatarWithTriangle = () =>
  <Box display='inline-flex' alignItems='center'>
    <Avatar marginLeft={majorScale(1)} marginRight={majorScale(1)} src='' imageSize='small'>Segment Sloth</Avatar>
    <Triangle aim='down'  display='inline-flex' fill='white' />
  </Box>

<NavigationBar left={'Sloth Corp Media'} right={<AvatarWithTriangle />}>Workspaces</NavigationBar>
\`\`\`

`}
          </Content>
          <NavigationBar left={'Sloth Corp Media'} right={<AvatarWithTriangle />}>Workspaces</NavigationBar>
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`children\` | node/string | undefined | if string wrapped in \`<NavigationBarTitle />\`
\`left\` | node | undefined | optional component next to logo
\`right\` | node | undefined | optional component in right corner
\`logo\`| node | \`<NavigationBarLogo />\` | formatted Segment logo
\`height\`| string | 58px | formatted Segment logo
`}
          </Content>
        </Pane>
      </App>
    ))
    .add('with title only', () => (
      <NavigationBar>Workspaces</NavigationBar>
    ))
    .add('with title and left component', () => (
      <NavigationBar left={'Sloth Corp Media'}>Workspaces</NavigationBar>
    ))
    .add('with title and right component', () => (
      <NavigationBar right={<AvatarWithTriangle />}>Workspaces</NavigationBar>
    ))
    .add('with title and left + right component', () => (
      <NavigationBar left={'Sloth Corp Media'} right={<AvatarWithTriangle />}>Workspaces</NavigationBar>
    ))
}
