import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  Pane,
  Body1,
  Text,
  Link,
  theme
} from '../components'
import Content from './Content'
const { majorScale } = theme

const quickBrownFox = 'The quick brown fox jumps over the lazy dog'

export default function paneStory (module) {
  storiesOf('Pane', module)
    .add('usage', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Pane

The Pane component is the base component to build layouts. Implements \`<Box />\`.

* Pane is almost the same as a Box, but is opiniated for backgrounds/layouts.

\`\`\`
<Pane dark padding={majorScale(2)}>
  <Body1>${quickBrownFox}</Body1>
</Pane>
\`\`\`

`}
          </Content>
          <Pane dark padding={majorScale(2)}>
            <Body1>{quickBrownFox}</Body1>
          </Pane>
          <Content markdown>
            {`

prop | type | description
-----|------|------------
\`dark\`    | boolean | dark background
\`white\`   | boolean  | white background
\`tint\` | boolean/1..2 | tinted background, tint={2} is darker
\`interactive\` | boolean | adds a border color on hover and active

`}
          </Content>
        </Pane>
      </App>
    ))
    .add('is a clickable card', () => (
      <App>
        <Pane is={Link} href='#' margin={majorScale(2)} interactive border white rounded shadow padding={majorScale(2)}><Text>{quickBrownFox}</Text></Pane>
      </App>
    ))
    .add('with dark background', () => (
      <App><Pane dark padding={majorScale(2)} clearfix><Text>{quickBrownFox}</Text></Pane></App>
    ))
    .add('with tint background', () => (
      <App>
        <Pane dark padding={majorScale(2)}>
          <Pane tint margin={majorScale(2)} padding={majorScale(2)} clearfix>Tint (1)</Pane>
          <Pane tint={2} margin={majorScale(2)} padding={majorScale(2)} clearfix>Tint 2</Pane>
        </Pane>
      </App>
    ))
    .add('with white background', () => (
      <App>
        <Pane dark padding={majorScale(2)}>
          <Pane white margin={majorScale(2)} padding={majorScale(2)} clearfix>White</Pane>
        </Pane>
      </App>
    ))
    .add('with rounded corners', () => (
      <App>
        <Pane dark clearfix>
          <Pane white padding={majorScale(2)} margin={majorScale(2)} rounded>Rounded (1)</Pane>
          <Pane white padding={majorScale(2)} margin={majorScale(2)} rounded={2}>Rounded 2</Pane>
        </Pane>
      </App>
    ))
    .add('with shadow', () => (
      <App>
        <Pane>
          <Pane white padding={majorScale(2)} margin={majorScale(2)} rounded shadow>Shadow (1)</Pane>
          <Pane white padding={majorScale(2)} margin={majorScale(2)} rounded shadow={2}>Shadow 2</Pane>
        </Pane>
      </App>
    ))
    .add('standalone', () => (
      <Pane>
        <Pane white padding={majorScale(2)} margin={majorScale(2)} rounded shadow>Shadow (1)</Pane>
        <Pane white padding={majorScale(2)} margin={majorScale(2)} rounded shadow={2}>Shadow 2</Pane>
      </Pane>
    ))
}
