import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  Pane,
  Radio,
  Box,
  theme
} from '../components'
import Content from './Content'
const { majorScale } = theme

class AdvancedExample extends React.Component {
  constructor () {
    super()

    this.state = {
      checkedParent: null,
      checkedChild: null,
      otherText: null
    }

    this.onSelectParent = this.onSelectParent.bind(this)
    this.onSelectChild = this.onSelectChild.bind(this)
  }

  render () {
    const { checkedParent, checkedChild } = this.state
    return (
      <form>
        <Radio name='exampleParent' value='parentBasic' checked={checkedParent === 'parentBasic'} onChange={this.onSelectParent}>Here is a basic example.</Radio>
        <Radio name='exampleParent' value='parentNested' checked={checkedParent === 'parentNested'} onChange={this.onSelectParent}>Click me to see what nested radio looks like.</Radio>
        {checkedParent === 'parentNested' &&
          <Box marginLeft={majorScale(3)}>
            <Radio name='exampleChild' value='childFirst' checked={checkedChild === 'childFirst'} onChange={this.onSelectChild}>Here is a nested radio button.</Radio>
            <Radio name='exampleChild' value='childSecond' checked={checkedChild === 'childSecond'} onChange={this.onSelectChild}>Nested radio buttons only show when their parent is selected.</Radio>
            <Radio name='exampleChild' value='childThird' checked={checkedChild === 'childThird'} onChange={this.onSelectChild}>They should be hidden once the parent gets unselected.</Radio>
            <Radio name='exampleChild' value='childFourth' checked={checkedChild === 'childFourth'} onChange={this.onSelectChild}>Here is a basic margin top example.</Radio>
          </Box>
        }
        <Radio name='exampleParent' value='parentLast' checked={checkedParent === 'parentLast'} onChange={this.onSelectParent}>Here is one last radio button.</Radio>
      </form>
    )
  }

  onSelectParent (e) {
    this.setState({
      checkedParent: e.target.value,
      checkedChild: null
    })
  }

  onSelectChild (e) {
    this.setState({
      checkedChild: e.target.value
    })
  }
}

export default function radioStory (module) {
  storiesOf('Radio', module)
    .add('usage', () => (
      <App white>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Radio

**Available since v4.1.0**

The Radio component is an \`input\` element. Implement the \`<Box />\` component.

\`\`\`
<Radio name='example' value='basic'>Here is a basic example.</Radio>
<Radio name='example' value='checked' checked>Here is basic checked example.</Radio>
<Radio name='example' value='margin' marginTop='25px'>Here is a basic margin top example.</Radio>
<Radio name='example' value='disabled' disabled>Here is a basic disabled state example.</Radio>
\`\`\`

`}
          </Content>
          <Radio name='example' value='basic'>Here is a basic example.</Radio>
          <Radio name='example' value='checked' checked>Here is basic checked example.</Radio>
          <Radio name='example' value='margin' marginTop='25px'>Here is a basic margin top example.</Radio>
          <Radio name='example' value='disabled' disabled>Here is a basic disabled state example.</Radio>

          <Content markdown>
            {`

# Advanced example

\`\`\`
class AdvancedExample extends React.Component {
  constructor () {
    super()

    this.state = {
      checkedParent: null,
      checkedChild: null,
      otherText: null
    }

    this.onSelectParent = this.onSelectParent.bind(this)
    this.onSelectChild = this.onSelectChild.bind(this)
  }

  render () {
    const { checkedParent, checkedChild } = this.state
    return (
      <form>
        <Radio name='exampleParent' value='parentBasic' checked={checkedParent === 'parentBasic'} onChange={this.onSelectParent}>Here is a basic example.</Radio>
        <Radio name='exampleParent' value='parentNested' checked={checkedParent === 'parentNested'} onChange={this.onSelectParent}>Click me to see what nested radio looks like.</Radio>
        {checkedParent === 'parentNested' &&
          <Box marginLeft={majorScale(3)}>
            <Radio name='exampleChild' value='childFirst' checked={checkedChild === 'childFirst'} onChange={this.onSelectChild}>Here is a nested radio button.</Radio>
            <Radio name='exampleChild' value='childSecond' checked={checkedChild === 'childSecond'} onChange={this.onSelectChild}>Nested radio buttons only show when their parent is selected.</Radio>
            <Radio name='exampleChild' value='childThird' checked={checkedChild === 'childThird'} onChange={this.onSelectChild}>They should be hidden once the parent gets unselected.</Radio>
            <Radio name='exampleChild' value='childFourth' checked={checkedChild === 'childFourth'} onChange={this.onSelectChild}>Here is a basic margin top example.</Radio>
          </Box>
        }
        <Radio name='exampleParent' value='parentLast' checked={checkedParent === 'parentLast'} onChange={this.onSelectParent}>Here is one last radio button.</Radio>
      </form>
    )
  }

  onSelectParent (e) {
    this.setState({
      checkedParent: e.target.value,
      checkedChild: null
    })
  }

  onSelectChild (e) {
    this.setState({
      checkedChild: e.target.value
    })
  }
}
\`\`\`

`}
          </Content>
          <AdvancedExample />
        </Pane>

      </App>
    ))
}
