import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  Text,
  Code,
  Pane,
  theme,
  Display1,
  Display2,
  Display3,
  Display4,
  Display5,
  Body1,
  Body2,
  Caps1,
  Caps2
} from '../components'
import Content from './Content'
const { majorScale } = theme

export default function textStory (module) {
  storiesOf('Text', module)
    .add('usage', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Text

The Text component is a \`p\` by default. Implements Box.

## Use our predefined text components

\`\`\`
<Display1>Display1</Display1>
<Display2>Display2</Display2>
<Display3>Display3</Display3>
<Display4>Display4</Display4>
<Display5>Display5</Display5>
<Body1>Body1</Body1>
<Body2>Body2</Body2>
<Caps1>Caps1</Caps1>
<Caps2>Caps2</Caps2>
\`\`\`

`}
          </Content>
          <Display1>Display1</Display1>
          <Display2>Display2</Display2>
          <Display3>Display3</Display3>
          <Display4>Display4</Display4>
          <Display5>Display5</Display5>
          <Body1>Body1</Body1>
          <Body2>Body2</Body2>
          <Caps1>Caps1</Caps1>
          <Caps2>Caps2</Caps2>
          <Content markdown>
            {`

## Using the Text component directly

You can use the Text component directly, but it needs to be configured with a textColor and sometimes a different semantic element.
Below is essentially the same as using the components described above.

\`\`\`
<Text is="h2" textColor="title" textStyle='display1'>Display (1)</Text>
<Text is="h2" textColor="title" textStyle='display2'>Display 2</Text>
<Text is="h2" textColor="title" textStyle='display3'>Display 3</Text>
<Text is="h2" textColor="title" textStyle='display4'>Display 4</Text>
<Text is="h2" textColor="title" textStyle='display5'>Display 5</Text>
<Text textColor="body" textStyle='body1'>Body (1)</Text>
<Text textColor="body" textStyle='body2'>Body 2</Text>
<Text textColor="body" textStyle='mono'>Mono</Text>
<Text textColor="body" textStyle='caps1'>Caps 1</Text>
<Text textColor="body" textStyle='caps2'>Caps 2</Text>
\`\`\`

`}
          </Content>
          <Text is='h2' textColor='title' textStyle='display1'>Display (1)</Text>
          <Text is='h2' textColor='title' textStyle='display2'>Display 2</Text>
          <Text is='h2' textColor='title' textStyle='display3'>Display 3</Text>
          <Text is='h2' textColor='title' textStyle='display4'>Display 4</Text>
          <Text is='h2' textColor='title' textStyle='display5'>Display 5</Text>
          <Text textColor='body' textStyle='body1'>Body (1)</Text>
          <Text textColor='body' textStyle='body2'>Body 2</Text>
          <Text textColor='body' textStyle='mono'>Mono</Text>
          <Text textColor='body' textStyle='caps1'>Caps 1</Text>
          <Text textColor='body' textStyle='caps2'>Caps 2</Text>
          <Content markdown>
            {`

## Text Styles API

Listed as a reference. Is not unique to \`<Text />\`, but is implemented on Box.

prop | type | description
-----|------|------------
\`textStyle\` | display1, display2, display3, display4, body1, body2, mono, caps1, caps2 | use text style
\`textColor\` | title, body, muted, white | use text color
`}
          </Content>
        </Pane>
      </App>
    ))
    .add('Truncate Text', () => (
      <App>
        <div style={{ width: 240 }}>
          <Text textStyle='body1' truncate>Truncate Text when it gets too long lorem ipsum</Text>
        </div>
      </App>
    ))
    .add('Muted (1) Text', () => (
      <App><Text muted>Soft Mute your text: <Code>{'<Text muted>...</Text>'}</Code></Text></App>
    ))
    .add('Muted 2 Text', () => (
      <App><Text muted={2}>Mute your text even more: <Code>{'<Text muted={2}>...</Text>'}</Code></Text></App>
    ))
    .add('standalone', () => (
      <Text muted={2}>Mute your text even more: <Code>{'<Text muted={2}>...</Text>'}</Code></Text>
    ))
}
