import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  Input,
  Pane,
  withLoader,
  theme
} from '../components'
import Content from './Content'
const { majorScale } = theme

const LoaderInput = withLoader(Input)
const LoaderInputStyled = withLoader(Input, {
  width: majorScale(8),
  height: majorScale(8),
  marginY: majorScale(4)
})

export default function inputStory (module) {
  storiesOf('withLoader', module)
    .add('usage', () => (
      <App white>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# withLoader

Higher Order Component for adding loading functionality to a component. Uses the \`<Spinner />\` component.

\`\`\`
const LoaderInput = withLoader(Input)
<LoaderInput isLoading />
\`\`\`

`}
          </Content>

          <LoaderInput isLoading />

          <Content markdown>
            {`
\`withLoader(component, spinnerProps)\`

prop | type | default | description
-----|------| --------|-------------
\`component\` | function | undefined | Component constructor
\`spinnerProps\` | object | \`{ marginX: 'auto', marginY: majorScale(8) }\` | Custom styles for \`<Spinner />\` (merged with default)
`}
          </Content>
        </Pane>
      </App>
    ))
    .add('standalone', () => (
      <LoaderInput isLoading />
    ))
    .add('with spinner props', () => (
      <LoaderInputStyled isLoading />
    ))
}
